pub fn create_backend(harness: &Harness) -> Result<Box<dyn AgentBackend>>Expand description
Create a backend from a harness specification.
This is the main factory function for creating backends.
pub fn create_backend(harness: &Harness) -> Result<Box<dyn AgentBackend>>Create a backend from a harness specification.
This is the main factory function for creating backends.