pub struct SessionHandle {
pub task_id: String,
pub session_id: Option<String>,
pub events: Receiver<StreamEvent>,
/* private fields */
}Expand description
Handle to a running headless session
Fields
task_id: StringTask ID this session is for
session_id: Option<String>Harness session ID (for continuation)
events: Receiver<StreamEvent>Event receiver
Implementations
Sourceimpl SessionHandle
impl SessionHandle
Sourcepub fn from_child(
task_id: String,
child: Child,
events: Receiver<StreamEvent>,
) -> Self
pub fn from_child( task_id: String, child: Child, events: Receiver<StreamEvent>, ) -> Self
Create a SessionHandle backed by a child process
Sourcepub fn into_parts(self) -> (Receiver<StreamEvent>, SessionProcess)
pub fn into_parts(self) -> (Receiver<StreamEvent>, SessionProcess)
Decompose the session into its event receiver and a killable process handle.
This allows the caller to own the events stream and process separately, e.g. for bridging events to a different channel while retaining the ability to kill the subprocess on cancellation.