Module monitor

Module monitor 

Monitor data structures for TUI integration

Provides data structures and functions for tracking spawn session state, to be consumed by a TUI control window.

Structs

AgentState
Information about a spawned agent
AgentView
Read-only view of an agent for display
SpawnSession
Spawn session state for TUI
SpawnStats
Statistics for a spawn session
StatusCounts
Status counts for header display
WaveTaskView
Read-only view of a task within a wave
WaveView
Read-only view of a wave for display

Enums

AgentStatus
State of a spawned agent
WaveTaskState
State of a task within a wave

Traits

MonitorableSession
Trait for sessions that can be displayed in the TUI monitor

Functions

delete_session
Delete a spawn session metadata file
list_sessions
List all spawn sessions
load_session
Load spawn session metadata
save_session
Save spawn session metadata
session_file
Get the path to a session’s metadata file
spawn_dir
Get the spawn metadata directory