pub struct SpawnConfig<'a> {
pub task_id: &'a str,
pub prompt: &'a str,
pub working_dir: &'a Path,
pub session_name: &'a str,
pub harness: Harness,
pub model: Option<&'a str>,
pub task_list_id: Option<&'a str>,
}Expand description
Configuration for spawning an agent in a tmux window.
Consolidates all spawn parameters into a single struct, replacing the previous 7 public spawn functions with one entry point.
Fields
task_id: &'a strprompt: &'a strworking_dir: &'a Pathsession_name: &'a strharness: Harnessmodel: Option<&'a str>task_list_id: Option<&'a str>Implementations