Monitor data structures for TUI integration
Provides data structures and functions for tracking spawn session state, to be consumed by a TUI control window.
Structs
- Agent
State - Information about a spawned agent
- Agent
View - Read-only view of an agent for display
- Spawn
Session - Spawn session state for TUI
- Spawn
Stats - Statistics for a spawn session
- Status
Counts - Status counts for header display
- Wave
Task View - Read-only view of a task within a wave
- Wave
View - Read-only view of a wave for display
Enums
- Agent
Status - State of a spawned agent
- Wave
Task State - State of a task within a wave
Traits
- Monitorable
Session - Trait for sessions that can be displayed in the TUI monitor
Functions
- delete_
session - Delete a spawn session metadata file
- list_
sessions - List all spawn sessions
- load_
session - Load spawn session metadata
- save_
session - Save spawn session metadata
- session_
file - Get the path to a session’s metadata file
- spawn_
dir - Get the spawn metadata directory